CellEndpoint class
Constructors
- CellEndpoint({required CellRegion region, required String url, int priority = 100})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- priority → int
-
final
- region → CellRegion
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited