CellRegion enum

Canonical cell regions. Mirrors libs/web-sdk CellRegion union + libs/mobile-sdk/tests/drift/cell-selection.json.

Inheritance
Available extensions

Values

usEast → const CellRegion
usWest → const CellRegion
euCentral → const CellRegion
apSouth → const CellRegion
apSoutheast → const CellRegion

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire String

Available on CellRegion, provided by the CellRegionWire extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CellRegion>
A constant List of the values in this enum, in order of their declaration.