PluginRegistry class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allPlugins(
) → List< AegisPlugin> -
dispatchConsentChange(
ConsentPreferences preferences) → void -
dispatchIdentify(
String userId, Map< String, dynamic> ? traits) → void -
dispatchReset(
) → void -
dispatchScreen(
String screenName, Map< String, dynamic> ? properties) → void -
list(
) → List< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
AegisPlugin plugin) → bool -
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
String name) → bool
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited