PrefetchBundle class
Constructors
-
PrefetchBundle({required String etag, required String generatedAt, required int ttlSeconds, required String invalidationTopic, required List<
PrefetchBundleCampaign> campaigns, required PrefetchBundleInbox inbox}) -
PrefetchBundle.fromJson(Map<
String, dynamic> j) -
factory
Properties
-
campaigns
→ List<
PrefetchBundleCampaign> -
final
- etag → String
-
final
- generatedAt → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inbox → PrefetchBundleInbox
-
final
- invalidationTopic → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ttlSeconds → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited