PrefetchBundleCampaign class

Constructors

PrefetchBundleCampaign({required String id, required String type, String? subType, required String title, required String body, String? backgroundColor, String? textColor, String? actionUrl, required int priority, Map<String, dynamic>? interactiveConfig, String? assignedVariantId, required bool inboxEnabled})
PrefetchBundleCampaign.fromJson(Map<String, dynamic> j)
factory

Properties

actionUrl String?
final
assignedVariantId String?
final
backgroundColor String?
final
body String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
inboxEnabled bool
final
interactiveConfig Map<String, dynamic>?
final
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subType String?
final
textColor String?
final
title String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited