PrefetchBundleInboxEntry class
Constructors
- PrefetchBundleInboxEntry({required String id, required String title, required String body, String? campaignId, required bool read})
-
PrefetchBundleInboxEntry.fromJson(Map<
String, dynamic> j) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited