AegisBootstrapResult class
Constructors
-
AegisBootstrapResult({required String propertyId, required String organizationId, required String workspaceId, required String propertyType, required bool pushEnabled, required bool inAppEnabled, required List<
String> allowedOrigins, required List<String> locationCodes, EventGovernanceHint? eventGovernance}) -
AegisBootstrapResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
allowedOrigins
→ List<
String> -
final
- eventGovernance → EventGovernanceHint?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inAppEnabled → bool
-
final
-
locationCodes
→ List<
String> -
final
- organizationId → String
-
final
- propertyId → String
-
final
- propertyType → String
-
final
- pushEnabled → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workspaceId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited