ConsentManager class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
categoryForEvent(
String eventName) → ConsentCategory -
current(
) → ConsentPreferences -
has(
ConsentCategory category) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(
void listener(ConsentPreferences)) → void Function() -
setConsent(
{bool? functional, bool? analytics, bool? marketing}) → void -
shouldEmit(
String eventName) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited