AegisPlugin class abstract

Constructors

AegisPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setter
requiredConsentCategory ConsentCategory?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConsentChange(ConsentPreferences preferences) → void
onDestroy() → void
onIdentify(String userId, Map<String, dynamic>? traits) → void
onInit() → void
onReset() → void
onScreen(String screenName, Map<String, dynamic>? properties) → void
onTrack(TrackEventLike event) PluginTrackDecision
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited