PrefetchBundleClient class
Constructors
Properties
- apiHost → String
-
final
- contactId ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizationId ↔ String?
-
getter/setter pair
- pollInterval → Duration
-
final
- propertyId ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId ↔ String?
-
getter/setter pair
- writeKey → String
-
final
Methods
-
addListener(
PrefetchBundleListener listener) → void Function() -
destroy(
) → void -
getBundle(
) → PrefetchBundle? -
getCampaigns(
) → List< PrefetchBundleCampaign> -
getInbox(
) → PrefetchBundleInbox -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
) → Future< PrefetchBundle?> -
start(
) → Future< PrefetchBundle?> -
stop(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateIdentity(
{String? contactId, String? userId, String? organizationId, String? propertyId}) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited